# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ProjectFileError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'project': 'list[str]',
        'file': 'list[str]',
        'content': 'list[str]',
        'name': 'list[str]',
        'path': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'project': 'project',
        'file': 'file',
        'content': 'content',
        'name': 'name',
        'path': 'path'
    }

    def __init__(self, non_field_errors=None, id=None, project=None, file=None, content=None, name=None, path=None):
        """
        ProjectFileError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._project = None
        self._file = None
        self._content = None
        self._name = None
        self._path = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if project is not None:
          self.project = project
        if file is not None:
          self.file = file
        if content is not None:
          self.content = content
        if name is not None:
          self.name = name
        if path is not None:
          self.path = path

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ProjectFileError.
        Errors not connected to any field

        :return: The non_field_errors of this ProjectFileError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ProjectFileError.
        Errors not connected to any field

        :param non_field_errors: The non_field_errors of this ProjectFileError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ProjectFileError.
        id field errors

        :return: The id of this ProjectFileError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ProjectFileError.
        id field errors

        :param id: The id of this ProjectFileError.
        :type: list[str]
        """

        self._id = id

    @property
    def project(self):
        """
        Gets the project of this ProjectFileError.
        project field errors

        :return: The project of this ProjectFileError.
        :rtype: list[str]
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Sets the project of this ProjectFileError.
        project field errors

        :param project: The project of this ProjectFileError.
        :type: list[str]
        """

        self._project = project

    @property
    def file(self):
        """
        Gets the file of this ProjectFileError.
        file field errors

        :return: The file of this ProjectFileError.
        :rtype: list[str]
        """
        return self._file

    @file.setter
    def file(self, file):
        """
        Sets the file of this ProjectFileError.
        file field errors

        :param file: The file of this ProjectFileError.
        :type: list[str]
        """

        self._file = file

    @property
    def content(self):
        """
        Gets the content of this ProjectFileError.
        base64_data field errors

        :return: The content of this ProjectFileError.
        :rtype: list[str]
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this ProjectFileError.
        base64_data field errors

        :param content: The content of this ProjectFileError.
        :type: list[str]
        """

        self._content = content

    @property
    def name(self):
        """
        Gets the name of this ProjectFileError.
        name field errors

        :return: The name of this ProjectFileError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ProjectFileError.
        name field errors

        :param name: The name of this ProjectFileError.
        :type: list[str]
        """

        self._name = name

    @property
    def path(self):
        """
        Gets the path of this ProjectFileError.
        path field errors

        :return: The path of this ProjectFileError.
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ProjectFileError.
        path field errors

        :param path: The path of this ProjectFileError.
        :type: list[str]
        """

        self._path = path

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ProjectFileError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """ AuthApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.auth_api.AuthApi()

    def tearDown(self):
        pass

    def test_auth_jwt_token_auth(self):
        """
        Test case for auth_jwt_token_auth

        Create JSON Web Token (JWT)
        """
        pass

    def test_auth_jwt_token_refresh(self):
        """
        Test case for auth_jwt_token_refresh

        Refresh a JSON Web Token (JWT)
        """
        pass

    def test_auth_jwt_token_verify(self):
        """
        Test case for auth_jwt_token_verify

        Validate JSON Web Token (JWT)
        """
        pass

    def test_auth_register(self):
        """
        Test case for auth_register

        Register a user
        """
        pass

    def test_oauth_login(self):
        """
        Test case for oauth_login

        
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class DockerHost(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'ip': 'str',
        'port': 'int',
        'status': 'str',
        'owner': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'ip': 'ip',
        'port': 'port',
        'status': 'status',
        'owner': 'owner'
    }

    def __init__(self, id=None, name=None, ip=None, port=None, status=None, owner=None):
        """
        DockerHost - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._ip = None
        self._port = None
        self._status = None
        self._owner = None

        if id is not None:
          self.id = id
        self.name = name
        self.ip = ip
        if port is not None:
          self.port = port
        if status is not None:
          self.status = status
        if owner is not None:
          self.owner = owner

    @property
    def id(self):
        """
        Gets the id of this DockerHost.
        Unique identifier for docker host as UUID.

        :return: The id of this DockerHost.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DockerHost.
        Unique identifier for docker host as UUID.

        :param id: The id of this DockerHost.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DockerHost.
        Docker host name.

        :return: The name of this DockerHost.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DockerHost.
        Docker host name.

        :param name: The name of this DockerHost.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def ip(self):
        """
        Gets the ip of this DockerHost.
        Docker host IPv4 address

        :return: The ip of this DockerHost.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """
        Sets the ip of this DockerHost.
        Docker host IPv4 address

        :param ip: The ip of this DockerHost.
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")

        self._ip = ip

    @property
    def port(self):
        """
        Gets the port of this DockerHost.
        Docker host port.

        :return: The port of this DockerHost.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this DockerHost.
        Docker host port.

        :param port: The port of this DockerHost.
        :type: int
        """

        self._port = port

    @property
    def status(self):
        """
        Gets the status of this DockerHost.
        Docker host status.

        :return: The status of this DockerHost.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DockerHost.
        Docker host status.

        :param status: The status of this DockerHost.
        :type: str
        """

        self._status = status

    @property
    def owner(self):
        """
        Gets the owner of this DockerHost.
        UUID of Docker host owner.

        :return: The owner of this DockerHost.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DockerHost.
        UUID of Docker host owner.

        :param owner: The owner of this DockerHost.
        :type: str
        """

        self._owner = owner

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DockerHost):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class HostsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def hosts_create(self, namespace, **kwargs):
        """
        Create a new host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_create(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_create_with_http_info(namespace, **kwargs)
        else:
            (data) = self.hosts_create_with_http_info(namespace, **kwargs)
            return data

    def hosts_create_with_http_info(self, namespace, **kwargs):
        """
        Create a new host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_create_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'dockerhost_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_create`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dockerhost_data' in params:
            body_params = params['dockerhost_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DockerHost',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def hosts_delete(self, namespace, host, **kwargs):
        """
        Delete a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_delete(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host: DockerHost unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_delete_with_http_info(namespace, host, **kwargs)
        else:
            (data) = self.hosts_delete_with_http_info(namespace, host, **kwargs)
            return data

    def hosts_delete_with_http_info(self, namespace, host, **kwargs):
        """
        Delete a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_delete_with_http_info(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host: DockerHost unique identifier expressed as UUID. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'host']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_delete`")
        # verify the required parameter 'host' is set
        if ('host' not in params) or (params['host'] is None):
            raise ValueError("Missing the required parameter `host` when calling `hosts_delete`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'host' in params:
            path_params['host'] = params['host']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/{host}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def hosts_list(self, namespace, **kwargs):
        """
        Get available hosts
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_list(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str limit: Limite when getting items.
        :param str offset: Offset when getting items.
        :param str name: Name, when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[DockerHost]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_list_with_http_info(namespace, **kwargs)
        else:
            (data) = self.hosts_list_with_http_info(namespace, **kwargs)
            return data

    def hosts_list_with_http_info(self, namespace, **kwargs):
        """
        Get available hosts
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_list_with_http_info(namespace, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team data. (required)
        :param str limit: Limite when getting items.
        :param str offset: Offset when getting items.
        :param str name: Name, when getting items.
        :param str ordering: Ordering when getting items.
        :return: list[DockerHost]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'limit', 'offset', 'name', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_list`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'name' in params:
            query_params.append(('name', params['name']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[DockerHost]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def hosts_read(self, namespace, host, **kwargs):
        """
        Get a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_read(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host: Unique identifier expressed as UUID or name. (required)
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_read_with_http_info(namespace, host, **kwargs)
        else:
            (data) = self.hosts_read_with_http_info(namespace, host, **kwargs)
            return data

    def hosts_read_with_http_info(self, namespace, host, **kwargs):
        """
        Get a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_read_with_http_info(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host: Unique identifier expressed as UUID or name. (required)
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'host']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_read`")
        # verify the required parameter 'host' is set
        if ('host' not in params) or (params['host'] is None):
            raise ValueError("Missing the required parameter `host` when calling `hosts_read`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'host' in params:
            path_params['host'] = params['host']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/{host}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DockerHost',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def hosts_replace(self, namespace, host, **kwargs):
        """
        Replace a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_replace(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host:  (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_replace_with_http_info(namespace, host, **kwargs)
        else:
            (data) = self.hosts_replace_with_http_info(namespace, host, **kwargs)
            return data

    def hosts_replace_with_http_info(self, namespace, host, **kwargs):
        """
        Replace a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_replace_with_http_info(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host:  (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'host', 'dockerhost_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_replace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_replace`")
        # verify the required parameter 'host' is set
        if ('host' not in params) or (params['host'] is None):
            raise ValueError("Missing the required parameter `host` when calling `hosts_replace`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'host' in params:
            path_params['host'] = params['host']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dockerhost_data' in params:
            body_params = params['dockerhost_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/{host}/', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DockerHost',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def hosts_update(self, namespace, host, **kwargs):
        """
        Update a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_update(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host:  (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.hosts_update_with_http_info(namespace, host, **kwargs)
        else:
            (data) = self.hosts_update_with_http_info(namespace, host, **kwargs)
            return data

    def hosts_update_with_http_info(self, namespace, host, **kwargs):
        """
        Update a host
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.hosts_update_with_http_info(namespace, host, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str namespace: User or team name. (required)
        :param str host:  (required)
        :param DockerHostData dockerhost_data:
        :return: DockerHost
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['namespace', 'host', 'dockerhost_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hosts_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `hosts_update`")
        # verify the required parameter 'host' is set
        if ('host' not in params) or (params['host'] is None):
            raise ValueError("Missing the required parameter `host` when calling `hosts_update`")


        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'host' in params:
            path_params['host'] = params['host']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dockerhost_data' in params:
            body_params = params['dockerhost_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/hosts/{host}/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DockerHost',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PlanData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metadata': 'object',
        'livemode': 'bool',
        'amount': 'int',
        'currency': 'str',
        'interval': 'list[str]',
        'interval_count': 'int',
        'name': 'str',
        'statement_descriptor': 'str',
        'trial_period_days': 'int'
    }

    attribute_map = {
        'metadata': 'metadata',
        'livemode': 'livemode',
        'amount': 'amount',
        'currency': 'currency',
        'interval': 'interval',
        'interval_count': 'interval_count',
        'name': 'name',
        'statement_descriptor': 'statement_descriptor',
        'trial_period_days': 'trial_period_days'
    }

    def __init__(self, metadata=None, livemode=None, amount=None, currency=None, interval=None, interval_count=None, name=None, statement_descriptor=None, trial_period_days=None):
        """
        PlanData - a model defined in Swagger
        """

        self._metadata = None
        self._livemode = None
        self._amount = None
        self._currency = None
        self._interval = None
        self._interval_count = None
        self._name = None
        self._statement_descriptor = None
        self._trial_period_days = None

        if metadata is not None:
          self.metadata = metadata
        if livemode is not None:
          self.livemode = livemode
        self.amount = amount
        if currency is not None:
          self.currency = currency
        self.interval = interval
        self.interval_count = interval_count
        self.name = name
        if statement_descriptor is not None:
          self.statement_descriptor = statement_descriptor
        if trial_period_days is not None:
          self.trial_period_days = trial_period_days

    @property
    def metadata(self):
        """
        Gets the metadata of this PlanData.
        Plan meta data.

        :return: The metadata of this PlanData.
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this PlanData.
        Plan meta data.

        :param metadata: The metadata of this PlanData.
        :type: object
        """

        self._metadata = metadata

    @property
    def livemode(self):
        """
        Gets the livemode of this PlanData.
        Is plan live, or not.

        :return: The livemode of this PlanData.
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """
        Sets the livemode of this PlanData.
        Is plan live, or not.

        :param livemode: The livemode of this PlanData.
        :type: bool
        """

        self._livemode = livemode

    @property
    def amount(self):
        """
        Gets the amount of this PlanData.
        Plan amount in currency.

        :return: The amount of this PlanData.
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this PlanData.
        Plan amount in currency.

        :param amount: The amount of this PlanData.
        :type: int
        """
        if amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")

        self._amount = amount

    @property
    def currency(self):
        """
        Gets the currency of this PlanData.
        Currency for plan.

        :return: The currency of this PlanData.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this PlanData.
        Currency for plan.

        :param currency: The currency of this PlanData.
        :type: str
        """

        self._currency = currency

    @property
    def interval(self):
        """
        Gets the interval of this PlanData.
        Plan interval.

        :return: The interval of this PlanData.
        :rtype: list[str]
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this PlanData.
        Plan interval.

        :param interval: The interval of this PlanData.
        :type: list[str]
        """
        if interval is None:
            raise ValueError("Invalid value for `interval`, must not be `None`")
        allowed_values = ["day", "week", "month", "year"]
        if not set(interval).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `interval` [{0}], must be a subset of [{1}]"
                .format(", ".join(map(str, set(interval)-set(allowed_values))),
                        ", ".join(map(str, allowed_values)))
            )

        self._interval = interval

    @property
    def interval_count(self):
        """
        Gets the interval_count of this PlanData.
        Number of intervals.

        :return: The interval_count of this PlanData.
        :rtype: int
        """
        return self._interval_count

    @interval_count.setter
    def interval_count(self, interval_count):
        """
        Sets the interval_count of this PlanData.
        Number of intervals.

        :param interval_count: The interval_count of this PlanData.
        :type: int
        """
        if interval_count is None:
            raise ValueError("Invalid value for `interval_count`, must not be `None`")

        self._interval_count = interval_count

    @property
    def name(self):
        """
        Gets the name of this PlanData.
        Plan name.

        :return: The name of this PlanData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this PlanData.
        Plan name.

        :param name: The name of this PlanData.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def statement_descriptor(self):
        """
        Gets the statement_descriptor of this PlanData.
        Plan description.

        :return: The statement_descriptor of this PlanData.
        :rtype: str
        """
        return self._statement_descriptor

    @statement_descriptor.setter
    def statement_descriptor(self, statement_descriptor):
        """
        Sets the statement_descriptor of this PlanData.
        Plan description.

        :param statement_descriptor: The statement_descriptor of this PlanData.
        :type: str
        """

        self._statement_descriptor = statement_descriptor

    @property
    def trial_period_days(self):
        """
        Gets the trial_period_days of this PlanData.
        Trial days for try and buy campaigns.

        :return: The trial_period_days of this PlanData.
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """
        Sets the trial_period_days of this PlanData.
        Trial days for try and buy campaigns.

        :param trial_period_days: The trial_period_days of this PlanData.
        :type: int
        """

        self._trial_period_days = trial_period_days

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PlanData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.hosts_api import HostsApi


class TestHostsApi(unittest.TestCase):
    """ HostsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.hosts_api.HostsApi()

    def tearDown(self):
        pass

    def test_hosts_create(self):
        """
        Test case for hosts_create

        Create a new host
        """
        pass

    def test_hosts_delete(self):
        """
        Test case for hosts_delete

        Delete a host
        """
        pass

    def test_hosts_list(self):
        """
        Test case for hosts_list

        Get available hosts
        """
        pass

    def test_hosts_read(self):
        """
        Test case for hosts_read

        Get a host
        """
        pass

    def test_hosts_replace(self):
        """
        Test case for hosts_replace

        Replace a host
        """
        pass

    def test_hosts_update(self):
        """
        Test case for hosts_update

        Update a host
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Subscription(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'plan': 'str',
        'stripe_id': 'str',
        'created': 'str',
        'livemode': 'bool',
        'application_fee_percent': 'float',
        'cancel_at_period_end': 'bool',
        'canceled_at': 'str',
        'current_period_start': 'str',
        'current_period_end': 'str',
        'start': 'str',
        'ended_at': 'str',
        'quantity': 'int',
        'status': 'str',
        'trial_start': 'str',
        'trial_end': 'str'
    }

    attribute_map = {
        'id': 'id',
        'plan': 'plan',
        'stripe_id': 'stripe_id',
        'created': 'created',
        'livemode': 'livemode',
        'application_fee_percent': 'application_fee_percent',
        'cancel_at_period_end': 'cancel_at_period_end',
        'canceled_at': 'canceled_at',
        'current_period_start': 'current_period_start',
        'current_period_end': 'current_period_end',
        'start': 'start',
        'ended_at': 'ended_at',
        'quantity': 'quantity',
        'status': 'status',
        'trial_start': 'trial_start',
        'trial_end': 'trial_end'
    }

    def __init__(self, id=None, plan=None, stripe_id=None, created=None, livemode=None, application_fee_percent=None, cancel_at_period_end=None, canceled_at=None, current_period_start=None, current_period_end=None, start=None, ended_at=None, quantity=None, status=None, trial_start=None, trial_end=None):
        """
        Subscription - a model defined in Swagger
        """

        self._id = None
        self._plan = None
        self._stripe_id = None
        self._created = None
        self._livemode = None
        self._application_fee_percent = None
        self._cancel_at_period_end = None
        self._canceled_at = None
        self._current_period_start = None
        self._current_period_end = None
        self._start = None
        self._ended_at = None
        self._quantity = None
        self._status = None
        self._trial_start = None
        self._trial_end = None

        if id is not None:
          self.id = id
        self.plan = plan
        if stripe_id is not None:
          self.stripe_id = stripe_id
        if created is not None:
          self.created = created
        if livemode is not None:
          self.livemode = livemode
        if application_fee_percent is not None:
          self.application_fee_percent = application_fee_percent
        if cancel_at_period_end is not None:
          self.cancel_at_period_end = cancel_at_period_end
        if canceled_at is not None:
          self.canceled_at = canceled_at
        if current_period_start is not None:
          self.current_period_start = current_period_start
        if current_period_end is not None:
          self.current_period_end = current_period_end
        if start is not None:
          self.start = start
        if ended_at is not None:
          self.ended_at = ended_at
        if quantity is not None:
          self.quantity = quantity
        if status is not None:
          self.status = status
        if trial_start is not None:
          self.trial_start = trial_start
        if trial_end is not None:
          self.trial_end = trial_end

    @property
    def id(self):
        """
        Gets the id of this Subscription.
        Unique identifier for suscription as UUID.

        :return: The id of this Subscription.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Subscription.
        Unique identifier for suscription as UUID.

        :param id: The id of this Subscription.
        :type: str
        """

        self._id = id

    @property
    def plan(self):
        """
        Gets the plan of this Subscription.
        Plan name.

        :return: The plan of this Subscription.
        :rtype: str
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """
        Sets the plan of this Subscription.
        Plan name.

        :param plan: The plan of this Subscription.
        :type: str
        """
        if plan is None:
            raise ValueError("Invalid value for `plan`, must not be `None`")

        self._plan = plan

    @property
    def stripe_id(self):
        """
        Gets the stripe_id of this Subscription.
        Stripe (payment processor) identifier.

        :return: The stripe_id of this Subscription.
        :rtype: str
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """
        Sets the stripe_id of this Subscription.
        Stripe (payment processor) identifier.

        :param stripe_id: The stripe_id of this Subscription.
        :type: str
        """

        self._stripe_id = stripe_id

    @property
    def created(self):
        """
        Gets the created of this Subscription.
        Date and time suscription was created.

        :return: The created of this Subscription.
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this Subscription.
        Date and time suscription was created.

        :param created: The created of this Subscription.
        :type: str
        """

        self._created = created

    @property
    def livemode(self):
        """
        Gets the livemode of this Subscription.
        Suscription live, or not.

        :return: The livemode of this Subscription.
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """
        Sets the livemode of this Subscription.
        Suscription live, or not.

        :param livemode: The livemode of this Subscription.
        :type: bool
        """

        self._livemode = livemode

    @property
    def application_fee_percent(self):
        """
        Gets the application_fee_percent of this Subscription.
        Application fee percent.

        :return: The application_fee_percent of this Subscription.
        :rtype: float
        """
        return self._application_fee_percent

    @application_fee_percent.setter
    def application_fee_percent(self, application_fee_percent):
        """
        Sets the application_fee_percent of this Subscription.
        Application fee percent.

        :param application_fee_percent: The application_fee_percent of this Subscription.
        :type: float
        """

        self._application_fee_percent = application_fee_percent

    @property
    def cancel_at_period_end(self):
        """
        Gets the cancel_at_period_end of this Subscription.
        Boolean value to determine whether plan cancels at the end of the period, or not.

        :return: The cancel_at_period_end of this Subscription.
        :rtype: bool
        """
        return self._cancel_at_period_end

    @cancel_at_period_end.setter
    def cancel_at_period_end(self, cancel_at_period_end):
        """
        Sets the cancel_at_period_end of this Subscription.
        Boolean value to determine whether plan cancels at the end of the period, or not.

        :param cancel_at_period_end: The cancel_at_period_end of this Subscription.
        :type: bool
        """

        self._cancel_at_period_end = cancel_at_period_end

    @property
    def canceled_at(self):
        """
        Gets the canceled_at of this Subscription.
        Date and time when plan was cancelled.

        :return: The canceled_at of this Subscription.
        :rtype: str
        """
        return self._canceled_at

    @canceled_at.setter
    def canceled_at(self, canceled_at):
        """
        Sets the canceled_at of this Subscription.
        Date and time when plan was cancelled.

        :param canceled_at: The canceled_at of this Subscription.
        :type: str
        """

        self._canceled_at = canceled_at

    @property
    def current_period_start(self):
        """
        Gets the current_period_start of this Subscription.
        Current suscription plan start date.

        :return: The current_period_start of this Subscription.
        :rtype: str
        """
        return self._current_period_start

    @current_period_start.setter
    def current_period_start(self, current_period_start):
        """
        Sets the current_period_start of this Subscription.
        Current suscription plan start date.

        :param current_period_start: The current_period_start of this Subscription.
        :type: str
        """

        self._current_period_start = current_period_start

    @property
    def current_period_end(self):
        """
        Gets the current_period_end of this Subscription.
        Current suscription plan end date.

        :return: The current_period_end of this Subscription.
        :rtype: str
        """
        return self._current_period_end

    @current_period_end.setter
    def current_period_end(self, current_period_end):
        """
        Sets the current_period_end of this Subscription.
        Current suscription plan end date.

        :param current_period_end: The current_period_end of this Subscription.
        :type: str
        """

        self._current_period_end = current_period_end

    @property
    def start(self):
        """
        Gets the start of this Subscription.
        Date and time for when plan started.

        :return: The start of this Subscription.
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this Subscription.
        Date and time for when plan started.

        :param start: The start of this Subscription.
        :type: str
        """

        self._start = start

    @property
    def ended_at(self):
        """
        Gets the ended_at of this Subscription.
        Date and time for when plan ended.

        :return: The ended_at of this Subscription.
        :rtype: str
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """
        Sets the ended_at of this Subscription.
        Date and time for when plan ended.

        :param ended_at: The ended_at of this Subscription.
        :type: str
        """

        self._ended_at = ended_at

    @property
    def quantity(self):
        """
        Gets the quantity of this Subscription.
        Quantity purchased as integer.

        :return: The quantity of this Subscription.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this Subscription.
        Quantity purchased as integer.

        :param quantity: The quantity of this Subscription.
        :type: int
        """

        self._quantity = quantity

    @property
    def status(self):
        """
        Gets the status of this Subscription.
        Suscription status.

        :return: The status of this Subscription.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Subscription.
        Suscription status.

        :param status: The status of this Subscription.
        :type: str
        """

        self._status = status

    @property
    def trial_start(self):
        """
        Gets the trial_start of this Subscription.
        Date and time for trial start.

        :return: The trial_start of this Subscription.
        :rtype: str
        """
        return self._trial_start

    @trial_start.setter
    def trial_start(self, trial_start):
        """
        Sets the trial_start of this Subscription.
        Date and time for trial start.

        :param trial_start: The trial_start of this Subscription.
        :type: str
        """

        self._trial_start = trial_start

    @property
    def trial_end(self):
        """
        Gets the trial_end of this Subscription.
        Date and time for trial end.

        :return: The trial_end of this Subscription.
        :rtype: str
        """
        return self._trial_end

    @trial_end.setter
    def trial_end(self, trial_end):
        """
        Sets the trial_end of this Subscription.
        Date and time for trial end.

        :param trial_end: The trial_end of this Subscription.
        :type: str
        """

        self._trial_end = trial_end

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from six import iteritems
from ..configuration import Configuration
from ..api_client import ApiClient


class DeploymentsApi(object):
    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def deployments_create_with_http_info(self, namespace, project,  **kwargs):
        all_params = ['namespace', 'project','deployment_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `create`")

        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_create`")
        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        if 'project' in params:
            path_params['project'] = params['project']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'deployment_data' in params:
            body_params = params['deployment_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client. \
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client. \
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Deployment',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def deployments_create(self, namespace, project, **kwargs):
        kwargs['_return_http_data_only'] = True
        (data) = self.deployments_create_with_http_info(namespace, project, **kwargs)
        return data

    def deployments_deploy_with_http_info(self, namespace, project, deployment, **kwargs):
        all_params = ['namespace', 'project', 'deployment']
        all_params.append("callback")
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_start" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_deploy`")
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `deployments_deploy`")
        # verify the required parameter 'deployment' is set
        if ('deployment' not in params) or (params['deployment'] is None):
            raise ValueError("Missing the required parameter `deployment` when calling `deployments_deploy`")

        collection_formats = {}

        path_params = {}
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'project' in params:
            path_params['project'] = params['project']
        if 'deployment' in params:
            path_params['deployment'] = params['deployment']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client. \
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client. \
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/{deployment}/deploy/', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def deployments_deploy(self, namespace, project, deployment, **kwargs):
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.deployments_deploy_with_http_info(namespace, project, deployment, **kwargs)
        else:
            (data) = self.deployments_deploy_with_http_info(namespace, project, deployment, **kwargs)
            return data

    def deployments_read(self, project, namespace, deployment, **kwargs):
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.deployments_read_with_http_info(project, namespace, deployment, **kwargs)
        else:
            (data) = self.deployments_read_with_http_info(project, namespace, deployment, **kwargs)
            return data

    def deployments_read_with_http_info(self, project, namespace, deployment, **kwargs):
        all_params = ['project', 'namespace', 'deployment']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_read`")
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `deployments_read`")
        # verify the required parameter 'deployment' is set
        if ('deployment' not in params) or (params['deployment'] is None):
            raise ValueError("Missing the required parameter `deployment` when calling `deployments_read`")


        collection_formats = {}

        path_params = {}
        if 'project' in params:
            path_params['project'] = params['project']
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'deployment' in params:
            path_params['deployment'] = params['deployment']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/{deployment}/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Deployment',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def deployments_delete(self, project, namespace, deployment, **kwargs):
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.deployments_delete_with_http_info(project, namespace, deployment, **kwargs)
        else:
            (data) = self.deployments_delete_with_http_info(project, namespace, deployment, **kwargs)
            return data

    def deployments_delete_with_http_info(self, project, namespace, deployment, **kwargs):
        all_params = ['project', 'namespace', 'deployment']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_delete`")
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `deployments_delete`")
        # verify the required parameter 'deployment' is set
        if ('deployment' not in params) or (params['deployment'] is None):
            raise ValueError("Missing the required parameter `deployment` when calling `deployments_delete`")


        collection_formats = {}

        path_params = {}
        if 'project' in params:
            path_params['project'] = params['project']
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'deployment' in params:
            path_params['deployment'] = params['deployment']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/{deployment}/', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def deployments_list(self, project, namespace, **kwargs):
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.deployments_list_with_http_info(project, namespace, **kwargs)
        else:
            (data) = self.deployments_list_with_http_info(project, namespace, **kwargs)
            return data

    def deployments_list_with_http_info(self, project, namespace, **kwargs):
        all_params = ['project', 'namespace', 'limit', 'offset', 'name', 'ordering']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_list`")
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `deployments_list`")

        collection_formats = {}

        path_params = {}
        if 'project' in params:
            path_params['project'] = params['project']
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'name' in params:
            query_params.append(('name', params['name']))
        if 'ordering' in params:
            query_params.append(('ordering', params['ordering']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client. \
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client. \
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Server]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def deployments_update(self, project, namespace, deployment, **kwargs):
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.deployments_update_with_http_info(project, namespace, deployment, **kwargs)
        else:
            (data) = self.deployments_update_with_http_info(project, namespace, deployment, **kwargs)
            return data

    def deployments_update_with_http_info(self, project, namespace, deployment, **kwargs):
        all_params = ['project', 'namespace', 'deployment', 'deployment_data']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deployments_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project' is set
        if ('project' not in params) or (params['project'] is None):
            raise ValueError("Missing the required parameter `project` when calling `deployments_update`")
        # verify the required parameter 'namespace' is set
        if ('namespace' not in params) or (params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `deployments_update`")
        # verify the required parameter 'deployment' is set
        if ('deployment' not in params) or (params['deployment'] is None):
            raise ValueError("Missing the required parameter `deployment` when calling `deployments_update`")


        collection_formats = {}

        path_params = {}
        if 'project' in params:
            path_params['project'] = params['project']
        if 'namespace' in params:
            path_params['namespace'] = params['namespace']
        if 'deployment' in params:
            path_params['deployment'] = params['deployment']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'deployment_data' in params:
            body_params = params['deployment_data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'text/html'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['jwt']

        return self.api_client.call_api('/v1/{namespace}/projects/{project}/deployments/{deployment}/', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Deployment',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """ UsersApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.users_api.UsersApi()

    def tearDown(self):
        pass

    def test_me(self):
        """
        Test case for me

        A convenience endpoint that is equivalent to GET /v1/users/profiles/<my user id>/
        """
        pass

    def test_user_avatar_delete(self):
        """
        Test case for user_avatar_delete

        Delete avatar
        """
        pass

    def test_user_avatar_get(self):
        """
        Test case for user_avatar_get

        Retrieve user's avatar
        """
        pass

    def test_user_avatar_set(self):
        """
        Test case for user_avatar_set

        Add user avatar
        """
        pass

    def test_user_avatar_update(self):
        """
        Test case for user_avatar_update

        Update a project file
        """
        pass

    def test_users_api_key_list(self):
        """
        Test case for users_api_key_list

        Retrieve account's API key
        """
        pass

    def test_users_api_key_reset(self):
        """
        Test case for users_api_key_reset

        Reset a user's API key
        """
        pass

    def test_users_create(self):
        """
        Test case for users_create

        Create new user
        """
        pass

    def test_users_delete(self):
        """
        Test case for users_delete

        Delete a user
        """
        pass

    def test_users_emails_create(self):
        """
        Test case for users_emails_create

        Create an email address
        """
        pass

    def test_users_emails_delete(self):
        """
        Test case for users_emails_delete

        Delete an email address
        """
        pass

    def test_users_emails_list(self):
        """
        Test case for users_emails_list

        Retrieve account email addresses
        """
        pass

    def test_users_emails_read(self):
        """
        Test case for users_emails_read

        Retrieve a user's email addresses
        """
        pass

    def test_users_emails_replace(self):
        """
        Test case for users_emails_replace

        Replace an email address
        """
        pass

    def test_users_emails_update(self):
        """
        Test case for users_emails_update

        Update an email address
        """
        pass

    def test_users_list(self):
        """
        Test case for users_list

        Get user list
        """
        pass

    def test_users_read(self):
        """
        Test case for users_read

        Retrieve a user
        """
        pass

    def test_users_ssh_key_list(self):
        """
        Test case for users_ssh_key_list

        Retrieve an SSH key
        """
        pass

    def test_users_ssh_key_reset(self):
        """
        Test case for users_ssh_key_reset

        Recreate an SSH key
        """
        pass

    def test_users_update(self):
        """
        Test case for users_update

        Update a user
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Collaborator(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'owner': 'bool',
        'user': 'str',
        'project': 'str',
        'joined': 'str',
        'username': 'str',
        'email': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'permissions': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'owner': 'owner',
        'user': 'user',
        'project': 'project',
        'joined': 'joined',
        'username': 'username',
        'email': 'email',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'permissions': 'permissions'
    }

    def __init__(self, id=None, owner=None, user=None, project=None, joined=None, username=None, email=None, first_name=None, last_name=None, permissions=None):
        """
        Collaborator - a model defined in Swagger
        """

        self._id = None
        self._owner = None
        self._user = None
        self._project = None
        self._joined = None
        self._username = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._permissions = None

        if id is not None:
          self.id = id
        if owner is not None:
          self.owner = owner
        if user is not None:
          self.user = user
        if project is not None:
          self.project = project
        if joined is not None:
          self.joined = joined
        if username is not None:
          self.username = username
        if email is not None:
          self.email = email
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        if permissions is not None:
          self.permissions = permissions

    @property
    def id(self):
        """
        Gets the id of this Collaborator.
        Collaborator unique identifier in UUID format.

        :return: The id of this Collaborator.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Collaborator.
        Collaborator unique identifier in UUID format.

        :param id: The id of this Collaborator.
        :type: str
        """

        self._id = id

    @property
    def owner(self):
        """
        Gets the owner of this Collaborator.
        Boolean that states whether collaborator is project owner, or not. 

        :return: The owner of this Collaborator.
        :rtype: bool
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this Collaborator.
        Boolean that states whether collaborator is project owner, or not. 

        :param owner: The owner of this Collaborator.
        :type: bool
        """

        self._owner = owner

    @property
    def user(self):
        """
        Gets the user of this Collaborator.
        Collaborator user name.

        :return: The user of this Collaborator.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Collaborator.
        Collaborator user name.

        :param user: The user of this Collaborator.
        :type: str
        """

        self._user = user

    @property
    def project(self):
        """
        Gets the project of this Collaborator.
        Collaborator project name.

        :return: The project of this Collaborator.
        :rtype: str
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Sets the project of this Collaborator.
        Collaborator project name.

        :param project: The project of this Collaborator.
        :type: str
        """

        self._project = project

    @property
    def joined(self):
        """
        Gets the joined of this Collaborator.
        Date time of when collaborator joined.

        :return: The joined of this Collaborator.
        :rtype: str
        """
        return self._joined

    @joined.setter
    def joined(self, joined):
        """
        Sets the joined of this Collaborator.
        Date time of when collaborator joined.

        :param joined: The joined of this Collaborator.
        :type: str
        """

        self._joined = joined

    @property
    def username(self):
        """
        Gets the username of this Collaborator.
        Collaborator's user name. This must be a valid user name within the system. 

        :return: The username of this Collaborator.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this Collaborator.
        Collaborator's user name. This must be a valid user name within the system. 

        :param username: The username of this Collaborator.
        :type: str
        """

        self._username = username

    @property
    def email(self):
        """
        Gets the email of this Collaborator.
        Collaborator's valid email address.

        :return: The email of this Collaborator.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Collaborator.
        Collaborator's valid email address.

        :param email: The email of this Collaborator.
        :type: str
        """

        self._email = email

    @property
    def first_name(self):
        """
        Gets the first_name of this Collaborator.
        Collaborator's first name.

        :return: The first_name of this Collaborator.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Collaborator.
        Collaborator's first name.

        :param first_name: The first_name of this Collaborator.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this Collaborator.
        Collaborator's last name.

        :return: The last_name of this Collaborator.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Collaborator.
        Collaborator's last name.

        :param last_name: The last_name of this Collaborator.
        :type: str
        """

        self._last_name = last_name

    @property
    def permissions(self):
        """
        Gets the permissions of this Collaborator.
        Collaborator permissions. Project creators are assigned owner priviledges by default. Permissions are write and read. 

        :return: The permissions of this Collaborator.
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """
        Sets the permissions of this Collaborator.
        Collaborator permissions. Project creators are assigned owner priviledges by default. Permissions are write and read. 

        :param permissions: The permissions of this Collaborator.
        :type: list[str]
        """
        allowed_values = ["write_project", "read_project"]
        if not set(permissions).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `permissions` [{0}], must be a subset of [{1}]"
                .format(", ".join(map(str, set(permissions)-set(allowed_values))),
                        ", ".join(map(str, allowed_values)))
            )

        self._permissions = permissions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Collaborator):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'name': 'list[str]',
        'created_at': 'list[str]',
        'image_name': 'list[str]',
        'server_size': 'list[str]',
        'startup_script': 'list[str]',
        'config': 'list[str]',
        'status': 'list[str]',
        'connected': 'list[str]',
        'host': 'list[str]',
        'endpoint': 'list[str]',
        'logs_url': 'list[str]',
        'status_url': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'name': 'name',
        'created_at': 'created_at',
        'image_name': 'image_name',
        'server_size': 'server_size',
        'startup_script': 'startup_script',
        'config': 'config',
        'status': 'status',
        'connected': 'connected',
        'host': 'host',
        'endpoint': 'endpoint',
        'logs_url': 'logs_url',
        'status_url': 'status_url'
    }

    def __init__(self, non_field_errors=None, id=None, name=None, created_at=None, image_name=None, server_size=None, startup_script=None, config=None, status=None, connected=None, host=None, endpoint=None, logs_url=None, status_url=None):
        """
        ServerError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._name = None
        self._created_at = None
        self._image_name = None
        self._server_size = None
        self._startup_script = None
        self._config = None
        self._status = None
        self._connected = None
        self._host = None
        self._endpoint = None
        self._logs_url = None
        self._status_url = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if created_at is not None:
          self.created_at = created_at
        if image_name is not None:
          self.image_name = image_name
        if server_size is not None:
          self.server_size = server_size
        if startup_script is not None:
          self.startup_script = startup_script
        if config is not None:
          self.config = config
        if status is not None:
          self.status = status
        if connected is not None:
          self.connected = connected
        if host is not None:
          self.host = host
        if endpoint is not None:
          self.endpoint = endpoint
        if logs_url is not None:
          self.logs_url = logs_url
        if status_url is not None:
          self.status_url = status_url

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this ServerError.
        Errors not connected to any field.

        :return: The non_field_errors of this ServerError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this ServerError.
        Errors not connected to any field.

        :param non_field_errors: The non_field_errors of this ServerError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this ServerError.
        id field errors.

        :return: The id of this ServerError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServerError.
        id field errors.

        :param id: The id of this ServerError.
        :type: list[str]
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServerError.
        name field errors.

        :return: The name of this ServerError.
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerError.
        name field errors.

        :param name: The name of this ServerError.
        :type: list[str]
        """

        self._name = name

    @property
    def created_at(self):
        """
        Gets the created_at of this ServerError.
        created_at field errors.

        :return: The created_at of this ServerError.
        :rtype: list[str]
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ServerError.
        created_at field errors.

        :param created_at: The created_at of this ServerError.
        :type: list[str]
        """

        self._created_at = created_at

    @property
    def image_name(self):
        """
        Gets the image_name of this ServerError.
        image_name field errors.

        :return: The image_name of this ServerError.
        :rtype: list[str]
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """
        Sets the image_name of this ServerError.
        image_name field errors.

        :param image_name: The image_name of this ServerError.
        :type: list[str]
        """

        self._image_name = image_name

    @property
    def server_size(self):
        """
        Gets the server_size of this ServerError.
        server_size field errors.

        :return: The server_size of this ServerError.
        :rtype: list[str]
        """
        return self._server_size

    @server_size.setter
    def server_size(self, server_size):
        """
        Sets the server_size of this ServerError.
        server_size field errors.

        :param server_size: The server_size of this ServerError.
        :type: list[str]
        """

        self._server_size = server_size

    @property
    def startup_script(self):
        """
        Gets the startup_script of this ServerError.
        startup_script field errors.

        :return: The startup_script of this ServerError.
        :rtype: list[str]
        """
        return self._startup_script

    @startup_script.setter
    def startup_script(self, startup_script):
        """
        Sets the startup_script of this ServerError.
        startup_script field errors.

        :param startup_script: The startup_script of this ServerError.
        :type: list[str]
        """

        self._startup_script = startup_script

    @property
    def config(self):
        """
        Gets the config of this ServerError.
        config field errors.

        :return: The config of this ServerError.
        :rtype: list[str]
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this ServerError.
        config field errors.

        :param config: The config of this ServerError.
        :type: list[str]
        """

        self._config = config

    @property
    def status(self):
        """
        Gets the status of this ServerError.
        status field errors.

        :return: The status of this ServerError.
        :rtype: list[str]
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ServerError.
        status field errors.

        :param status: The status of this ServerError.
        :type: list[str]
        """

        self._status = status

    @property
    def connected(self):
        """
        Gets the connected of this ServerError.
        connected field errors.

        :return: The connected of this ServerError.
        :rtype: list[str]
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """
        Sets the connected of this ServerError.
        connected field errors.

        :param connected: The connected of this ServerError.
        :type: list[str]
        """

        self._connected = connected

    @property
    def host(self):
        """
        Gets the host of this ServerError.
        host field errors.

        :return: The host of this ServerError.
        :rtype: list[str]
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this ServerError.
        host field errors.

        :param host: The host of this ServerError.
        :type: list[str]
        """

        self._host = host

    @property
    def endpoint(self):
        """
        Gets the endpoint of this ServerError.
        endpoint field errors.

        :return: The endpoint of this ServerError.
        :rtype: list[str]
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this ServerError.
        endpoint field errors.

        :param endpoint: The endpoint of this ServerError.
        :type: list[str]
        """

        self._endpoint = endpoint

    @property
    def logs_url(self):
        """
        Gets the logs_url of this ServerError.
        logs_url field errors.

        :return: The logs_url of this ServerError.
        :rtype: list[str]
        """
        return self._logs_url

    @logs_url.setter
    def logs_url(self, logs_url):
        """
        Sets the logs_url of this ServerError.
        logs_url field errors.

        :param logs_url: The logs_url of this ServerError.
        :type: list[str]
        """

        self._logs_url = logs_url

    @property
    def status_url(self):
        """
        Gets the status_url of this ServerError.
        status_url field errors.

        :return: The status_url of this ServerError.
        :rtype: list[str]
        """
        return self._status_url

    @status_url.setter
    def status_url(self, status_url):
        """
        Sets the status_url of this ServerError.
        status_url field errors.

        :param status_url: The status_url of this ServerError.
        :type: list[str]
        """

        self._status_url = status_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerSize(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'cpu': 'int',
        'memory': 'int',
        'active': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'cpu': 'cpu',
        'memory': 'memory',
        'active': 'active'
    }

    def __init__(self, id=None, name=None, cpu=None, memory=None, active=None):
        """
        ServerSize - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._cpu = None
        self._memory = None
        self._active = None

        if id is not None:
          self.id = id
        self.name = name
        self.cpu = cpu
        self.memory = memory
        if active is not None:
          self.active = active

    @property
    def id(self):
        """
        Gets the id of this ServerSize.
        Server size unique identifier.

        :return: The id of this ServerSize.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServerSize.
        Server size unique identifier.

        :param id: The id of this ServerSize.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ServerSize.
        Server size name.

        :return: The name of this ServerSize.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerSize.
        Server size name.

        :param name: The name of this ServerSize.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def cpu(self):
        """
        Gets the cpu of this ServerSize.
        CPU availability, equivalent to --cpus=<value>. For example if a host has 2 CPU's, then a value of 1.5 would be limit the container to using all of the first CPU and half of the second CPU. 

        :return: The cpu of this ServerSize.
        :rtype: int
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu):
        """
        Sets the cpu of this ServerSize.
        CPU availability, equivalent to --cpus=<value>. For example if a host has 2 CPU's, then a value of 1.5 would be limit the container to using all of the first CPU and half of the second CPU. 

        :param cpu: The cpu of this ServerSize.
        :type: int
        """
        if cpu is None:
            raise ValueError("Invalid value for `cpu`, must not be `None`")

        self._cpu = cpu

    @property
    def memory(self):
        """
        Gets the memory of this ServerSize.
        Memory restriction for container.

        :return: The memory of this ServerSize.
        :rtype: int
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """
        Sets the memory of this ServerSize.
        Memory restriction for container.

        :param memory: The memory of this ServerSize.
        :type: int
        """
        if memory is None:
            raise ValueError("Invalid value for `memory`, must not be `None`")

        self._memory = memory

    @property
    def active(self):
        """
        Gets the active of this ServerSize.
        States whether the Server size is active, or not.

        :return: The active of this ServerSize.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this ServerSize.
        States whether the Server size is active, or not.

        :param active: The active of this ServerSize.
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerSize):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .action import Action
from .auth_token import AuthToken
from .auth_token_data import AuthTokenData
from .auth_token_error import AuthTokenError
from .card import Card
from .card_data_post import CardDataPost
from .card_data_putand_patch import CardDataPutandPatch
from .card_error import CardError
from .card_update_error import CardUpdateError
from .collaborator import Collaborator
from .collaborator_data import CollaboratorData
from .collaborator_error import CollaboratorError
from .customer import Customer
from .customer_data import CustomerData
from .customer_error import CustomerError
from .deployment import Deployment
from .deployment_data import DeploymentData
from .deployment_config import DeploymentConfig
from .docker_host import DockerHost
from .docker_host_data import DockerHostData
from .docker_host_error import DockerHostError
from .email import Email
from .email_data import EmailData
from .email_error import EmailError
from .invoice import Invoice
from .invoice_item import InvoiceItem
from .jwt import JWT
from .jwt_data import JWTData
from .jwt_error import JWTError
from .not_found import NotFound
from .notification import Notification
from .notification_error import NotificationError
from .notification_list_update_data import NotificationListUpdateData
from .notification_settings import NotificationSettings
from .notification_settings_data import NotificationSettingsData
from .notification_settings_error import NotificationSettingsError
from .notification_update_data import NotificationUpdateData
from .plan import Plan
from .plan_data import PlanData
from .plan_error import PlanError
from .project import Project
from .project_copy_data import ProjectCopyData
from .project_copy_data_1 import ProjectCopyData1
from .project_data import ProjectData
from .project_error import ProjectError
from .project_file import ProjectFile
from .project_file_error import ProjectFileError
from .refresh_json_web_token import RefreshJSONWebToken
from .refresh_json_web_token_data import RefreshJSONWebTokenData
from .refresh_json_web_token_error import RefreshJSONWebTokenError
from .search import Search
from .server import Server
from .server_action import ServerAction
from .server_action_data import ServerActionData
from .server_action_error import ServerActionError
from .server_config import ServerConfig
from .server_data import ServerData
from .server_error import ServerError
from .server_run_statistics import ServerRunStatistics
from .server_run_statistics_data import ServerRunStatisticsData
from .server_run_statistics_error import ServerRunStatisticsError
from .server_size import ServerSize
from .server_size_data import ServerSizeData
from .server_size_error import ServerSizeError
from .server_statistics import ServerStatistics
from .server_statistics_data import ServerStatisticsData
from .server_statistics_error import ServerStatisticsError
from .ssh_tunnel import SshTunnel
from .ssh_tunnel_data import SshTunnelData
from .ssh_tunnel_error import SshTunnelError
from .subscription import Subscription
from .subscription_data import SubscriptionData
from .subscription_error import SubscriptionError
from .user import User
from .user_data import UserData
from .user_error import UserError
from .user_profile import UserProfile
from .user_profile_error import UserProfileError
from .verify_json_web_token import VerifyJSONWebToken
from .verify_json_web_token_data import VerifyJSONWebTokenData
from .verify_json_web_token_error import VerifyJSONWebTokenError
from .webhook import Webhook



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ServerData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'image_name': 'str',
        'server_size': 'str',
        'startup_script': 'str',
        'config': 'ServerConfig',
        'connected': 'list[str]',
        'host': 'str'
    }

    attribute_map = {
        'name': 'name',
        'image_name': 'image_name',
        'server_size': 'server_size',
        'startup_script': 'startup_script',
        'config': 'config',
        'connected': 'connected',
        'host': 'host'
    }

    def __init__(self, name=None, image_name=None, server_size=None, startup_script=None, config=None, connected=None, host=None):
        """
        ServerData - a model defined in Swagger
        """

        self._name = None
        self._image_name = None
        self._server_size = None
        self._startup_script = None
        self._config = None
        self._connected = None
        self._host = None

        self.name = name
        if image_name is not None:
          self.image_name = image_name
        if server_size is not None:
          self.server_size = server_size
        if startup_script is not None:
          self.startup_script = startup_script
        if config is not None:
          self.config = config
        if connected is not None:
          self.connected = connected
        if host is not None:
          self.host = host

    @property
    def name(self):
        """
        Gets the name of this ServerData.
        Server name.

        :return: The name of this ServerData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ServerData.
        Server name.

        :param name: The name of this ServerData.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def image_name(self):
        """
        Gets the image_name of this ServerData.
        Image name.

        :return: The image_name of this ServerData.
        :rtype: str
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """
        Sets the image_name of this ServerData.
        Image name.

        :param image_name: The image_name of this ServerData.
        :type: str
        """

        self._image_name = image_name

    @property
    def server_size(self):
        """
        Gets the server_size of this ServerData.
        Server size unique identifier.

        :return: The server_size of this ServerData.
        :rtype: str
        """
        return self._server_size

    @server_size.setter
    def server_size(self, server_size):
        """
        Sets the server_size of this ServerData.
        Server size unique identifier.

        :param server_size: The server_size of this ServerData.
        :type: str
        """

        self._server_size = server_size

    @property
    def startup_script(self):
        """
        Gets the startup_script of this ServerData.
        Startup script to run when launching server.

        :return: The startup_script of this ServerData.
        :rtype: str
        """
        return self._startup_script

    @startup_script.setter
    def startup_script(self, startup_script):
        """
        Sets the startup_script of this ServerData.
        Startup script to run when launching server.

        :param startup_script: The startup_script of this ServerData.
        :type: str
        """

        self._startup_script = startup_script

    @property
    def config(self):
        """
        Gets the config of this ServerData.
        Server configuration option. Values are jupyter, restful and cron.

        :return: The config of this ServerData.
        :rtype: ServerConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this ServerData.
        Server configuration option. Values are jupyter, restful and cron.

        :param config: The config of this ServerData.
        :type: ServerConfig
        """

        self._config = config

    @property
    def connected(self):
        """
        Gets the connected of this ServerData.
        Array of other servers the server is connected to.

        :return: The connected of this ServerData.
        :rtype: list[str]
        """
        return self._connected

    @connected.setter
    def connected(self, connected):
        """
        Sets the connected of this ServerData.
        Array of other servers the server is connected to.

        :param connected: The connected of this ServerData.
        :type: list[str]
        """

        self._connected = connected

    @property
    def host(self):
        """
        Gets the host of this ServerData.
        External host IPv4 address or hostname.

        :return: The host of this ServerData.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this ServerData.
        External host IPv4 address or hostname.

        :param host: The host of this ServerData.
        :type: str
        """

        self._host = host

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Project(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'team': 'str',
        'private': 'bool',
        'last_updated': 'str',
        'owner': 'str',
        'collaborators': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'team': 'team',
        'private': 'private',
        'last_updated': 'last_updated',
        'owner': 'owner',
        'collaborators': 'collaborators'
    }

    def __init__(self, id=None, name=None, description=None, team=None, private=None, last_updated=None, owner=None, collaborators=None):
        """
        Project - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._team = None
        self._private = None
        self._last_updated = None
        self._owner = None
        self._collaborators = None

        if id is not None:
          self.id = id
        self.name = name
        if description is not None:
          self.description = description
        if team is not None:
          self.team = team
        if private is not None:
          self.private = private
        if last_updated is not None:
          self.last_updated = last_updated
        if owner is not None:
          self.owner = owner
        if collaborators is not None:
          self.collaborators = collaborators

    @property
    def id(self):
        """
        Gets the id of this Project.
        Unique identifier for project as UUID.

        :return: The id of this Project.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Project.
        Unique identifier for project as UUID.

        :param id: The id of this Project.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Project.
        Project name.

        :return: The name of this Project.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Project.
        Project name.

        :param name: The name of this Project.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Project.
        Project description.

        :return: The description of this Project.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Project.
        Project description.

        :param description: The description of this Project.
        :type: str
        """

        self._description = description

    @property
    def team(self):
        """
        Gets the team of this Project.
        Project team name.

        :return: The team of this Project.
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this Project.
        Project team name.

        :param team: The team of this Project.
        :type: str
        """

        self._team = team

    @property
    def private(self):
        """
        Gets the private of this Project.
        Value that states whether project is private or public.

        :return: The private of this Project.
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """
        Sets the private of this Project.
        Value that states whether project is private or public.

        :param private: The private of this Project.
        :type: bool
        """

        self._private = private

    @property
    def last_updated(self):
        """
        Gets the last_updated of this Project.
        Date and time when project was last updated.

        :return: The last_updated of this Project.
        :rtype: str
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """
        Sets the last_updated of this Project.
        Date and time when project was last updated.

        :param last_updated: The last_updated of this Project.
        :type: str
        """

        self._last_updated = last_updated

    @property
    def owner(self):
        """
        Gets the owner of this Project.
        Username of project owner.

        :return: The owner of this Project.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this Project.
        Username of project owner.

        :param owner: The owner of this Project.
        :type: str
        """

        self._owner = owner

    @property
    def collaborators(self):
        """
        Gets the collaborators of this Project.
        Array of project collaborators.

        :return: The collaborators of this Project.
        :rtype: list[str]
        """
        return self._collaborators

    @collaborators.setter
    def collaborators(self, collaborators):
        """
        Sets the collaborators of this Project.
        Array of project collaborators.

        :param collaborators: The collaborators of this Project.
        :type: list[str]
        """

        self._collaborators = collaborators

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Project):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from six import iteritems
from pprint import pformat


class Deployment(object):
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'project': 'str',
        'created_at': 'str',
        'created_by': 'str',
        'config': 'object',
        'framework': 'str',
        'runtime': 'str',
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'project': 'project',
        'created_at': 'created_at',
        'created_by': 'created_by',
        'config': 'config',
        'framework': 'framework',
        'runtime': 'runtime',
    }

    def __init__(self, id=None, name=None, project=None, created_at=None, created_by=None, config=None, status=None, endpoint=None, framework=None, runtime=None):
        """
        Server - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._project = None
        self._created_at = None
        self._created_by = None
        self._config = None
        self._status = None
        self._endpoint = None
        self._framework = None
        self._runtime = None

        if id is not None:
          self.id = id
        self.name = name
        if project is not None:
          self.project = project
        if created_at is not None:
          self.created_at = created_at
        if created_by is not None:
          self.created_by = created_by
        if config is not None:
          self.config = config
        if status is not None:
          self.status = status
        if endpoint is not None:
            self.endpoint = endpoint
        if framework is not None:
            self.framework = framework
        if runtime is not None:
            self.runtime = runtime

    @property
    def id(self):
        """
        Gets the id of this Server.
        Server unique identifier in UUID format.

        :return: The id of this Server.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Server.
        Server unique identifier in UUID format.

        :param id: The id of this Server.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Server.
        Server name.

        :return: The name of this Server.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Server.
        Server name.

        :param name: The name of this Server.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def project(self):
        """
        Gets the project of this Server.
        Project name.

        :return: The project of this Server.
        :rtype: str
        """
        return self._project

    @project.setter
    def project(self, project):
        """
        Sets the project of this Server.
        Project name.

        :param project: The project of this Server.
        :type: str
        """

        self._project = project

    @property
    def created_at(self):
        """
        Gets the created_at of this Server.
        Date and time when server was created.

        :return: The created_at of this Server.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this Server.
        Date and time when server was created.

        :param created_at: The created_at of this Server.
        :type: str
        """

        self._created_at = created_at

    @property
    def created_by(self):
        """
        Gets the created_by of this Server.
        User that created server.

        :return: The created_by of this Server.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Server.
        User that created server.

        :param created_by: The created_by of this Server.
        :type: str
        """

        self._created_by = created_by

    @property
    def config(self):
        """
        Gets the config of this Server.
        Server configuration option. Values are jupyter, restful and cron.

        :return: The config of this Server.
        :rtype: object
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this Server.
        Server configuration option. Values are jupyter, restful and cron.

        :param config: The config of this Server.
        :type: object
        """

        self._config = config

    @property
    def status(self):
        """
        Gets the status of this Server.
        Server status, such as Running or Error.

        :return: The status of this Server.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Server.
        Server status, such as Running or Error.

        :param status: The status of this Server.
        :type: str
        """
        allowed_values = ["Stopped", "Running", "Error"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def framework(self):
        return self._framework

    @framework.setter
    def framework(self, framework):

        self._framework = framework

    @property
    def runtime(self):
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):

        self._runtime = runtime

    @property
    def endpoint(self):
        """
        Gets the endpoint of this Server.
        Server endpoint path.

        :return: The endpoint of this Server.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this Server.
        Server endpoint path.

        :param endpoint: The endpoint of this Server.
        :type: str
        """

        self._endpoint = endpoint
    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Deployment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.action import Action
from .models.auth_token import AuthToken
from .models.auth_token_data import AuthTokenData
from .models.auth_token_error import AuthTokenError
from .models.card import Card
from .models.card_data_post import CardDataPost
from .models.card_data_putand_patch import CardDataPutandPatch
from .models.card_error import CardError
from .models.card_update_error import CardUpdateError
from .models.collaborator import Collaborator
from .models.collaborator_data import CollaboratorData
from .models.collaborator_error import CollaboratorError
from .models.customer import Customer
from .models.customer_data import CustomerData
from .models.customer_error import CustomerError
from .models.deployment import Deployment
from .models.deployment_data import DeploymentData
from .models.deployment_config import DeploymentConfig
from .models.docker_host import DockerHost
from .models.docker_host_data import DockerHostData
from .models.docker_host_error import DockerHostError
from .models.email import Email
from .models.email_data import EmailData
from .models.email_error import EmailError
from .models.invoice import Invoice
from .models.invoice_item import InvoiceItem
from .models.jwt import JWT
from .models.jwt_data import JWTData
from .models.jwt_error import JWTError
from .models.not_found import NotFound
from .models.notification import Notification
from .models.notification_error import NotificationError
from .models.notification_list_update_data import NotificationListUpdateData
from .models.notification_settings import NotificationSettings
from .models.notification_settings_data import NotificationSettingsData
from .models.notification_settings_error import NotificationSettingsError
from .models.notification_update_data import NotificationUpdateData
from .models.plan import Plan
from .models.plan_data import PlanData
from .models.plan_error import PlanError
from .models.project import Project
from .models.project_copy_data import ProjectCopyData
from .models.project_copy_data_1 import ProjectCopyData1
from .models.project_data import ProjectData
from .models.project_error import ProjectError
from .models.project_file import ProjectFile
from .models.project_file_error import ProjectFileError
from .models.refresh_json_web_token import RefreshJSONWebToken
from .models.refresh_json_web_token_data import RefreshJSONWebTokenData
from .models.refresh_json_web_token_error import RefreshJSONWebTokenError
from .models.search import Search
from .models.server import Server
from .models.server_action import ServerAction
from .models.server_action_data import ServerActionData
from .models.server_action_error import ServerActionError
from .models.server_config import ServerConfig
from .models.server_data import ServerData
from .models.server_error import ServerError
from .models.server_run_statistics import ServerRunStatistics
from .models.server_run_statistics_data import ServerRunStatisticsData
from .models.server_run_statistics_error import ServerRunStatisticsError
from .models.server_size import ServerSize
from .models.server_size_data import ServerSizeData
from .models.server_size_error import ServerSizeError
from .models.server_statistics import ServerStatistics
from .models.server_statistics_data import ServerStatisticsData
from .models.server_statistics_error import ServerStatisticsError
from .models.ssh_tunnel import SshTunnel
from .models.ssh_tunnel_data import SshTunnelData
from .models.ssh_tunnel_error import SshTunnelError
from .models.subscription import Subscription
from .models.subscription_data import SubscriptionData
from .models.subscription_error import SubscriptionError
from .models.user import User
from .models.user_data import UserData
from .models.user_error import UserError
from .models.user_profile import UserProfile
from .models.user_profile_error import UserProfileError
from .models.verify_json_web_token import VerifyJSONWebToken
from .models.verify_json_web_token_data import VerifyJSONWebTokenData
from .models.verify_json_web_token_error import VerifyJSONWebTokenError
from .models.webhook import Webhook

# import apis into sdk package
from .apis.auth_api import AuthApi
from .apis.billing_api import BillingApi
from .apis.deployments_api import DeploymentsApi
from .apis.hosts_api import HostsApi
from .apis.notifications_api import NotificationsApi
from .apis.projects_api import ProjectsApi
from .apis.search_api import SearchApi
from .apis.servers_api import ServersApi
from .apis.users_api import UsersApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
